@@ -2,7 +2,7 @@
 # @Time    : 19/10/12 下午12:13
 # @Author  : cc
 # @FileName: __init__.py.py
-from .RedisQueue import *
+from .producter_consumer import *
 from .init_config_file import use_config_form_distributed_frame_config_module
 
 use_config_form_distributed_frame_config_module()
