@@ -2,16 +2,19 @@
 # @Time    : 2020/7/17 19:30
 # @Author  : CC
 # @Desc    : t_queue.py
+import time
+
 from redis_queue_tool import task_deco
 
 
 def t_demo1():
-    @task_deco('test1', qps=10, threads_num=10, max_retry_times=3)  # 消费函数上新增任务队列装饰器
+    @task_deco('test1', qps=30, threads_num=30, max_retry_times=3, ack=True)  # 消费函数上新增任务队列装饰器
     def f1(a, b):
-        print(f"a:{a},b:{b}")
+        time.sleep(10)
+        print(f"t_demo1,a:{a},b:{b}")
 
     # 发布任务
-    for i in range(1, 51):
+    for i in range(1, 31):
         f1.pub(i, i + 1)  # 或者 f1.publish_redispy(i,i+1)
 
     # 消费任务
@@ -24,14 +27,14 @@ def t_demo2():
     for zz in range(1, 51):
         # 写入字典任务 {"a":zz,"b":zz,"c":zz}
         param = {"a": zz, "b": zz, "c": zz}
-        RedisPublish(queue_name='test2').publish_redispy(param)
+        RedisPublish(queue_name='test2', fliter_rep=False).publish_redispy(param)
 
     def print_msg_dict(a, b, c):
-        print(f"msg_dict:{a},{b},{c}")
+        print(f"t_demo2:{a},{b},{c}")
 
     # 消费多参数类型任务 queue_name消费队列名称 qps每秒消费任务数(默认没有限制)
     RedisCustomer(queue_name='test2', consuming_function=print_msg_dict,
-                  qps=50).start_consuming_message()
+                  qps=50, fliter_rep=True).start_consuming_message()
 
 
 def t_demo3():
@@ -45,7 +48,7 @@ def t_demo3():
     RedisPublish(queue_name='test3', max_push_size=100).publish_redispy_list(result)
 
     def print_msg_dict1(a, b, c):
-        print(f"msg_dict1:{a},{b},{c}")
+        print(f"t_demo3:{a},{b},{c}")
 
     # 消费者类型 string 支持('thread','gevent') 默认thread，若使用gevent请在代码开头加入：from gevent import monkey monkey.patch_all()
     RedisCustomer(queue_name='test3', consuming_function=print_msg_dict1, customer_type='gevent',
@@ -56,22 +59,22 @@ def t_demo4():
     from redis_queue_tool import RedisPublish, RedisCustomer
 
     for zz in range(1, 51):
-        RedisPublish(queue_name='test4', middleware='sqlite').publish_redispy(a=zz, b=zz, c=zz)
+        RedisPublish(queue_name='test4', middleware='sqlite', fliter_rep=False).publish_redispy(a=zz, b=zz, c=zz)
 
     def print_msg_dict2(a, b, c):
-        print(f"msg_dict:{a},{b},{c}")
+        print(f"t_demo4:{a},{b},{c}")
 
     RedisCustomer(queue_name='test4', consuming_function=print_msg_dict2, middleware='sqlite',
-                  qps=50).start_consuming_message()
+                  qps=50, fliter_rep=True).start_consuming_message()
 
 
 def t_demo5():
     from redis_queue_tool import task_deco
 
-    @task_deco('test5')  # 消费函数上新增任务队列装饰器
+    @task_deco('test5', fliter_rep=True)  # 消费函数上新增任务队列装饰器
     def f(a, b):
-        print(f"a:{a},b:{b}")
-        raise Exception('测试异常输出'*5)
+        print(f"t_demo5,a:{a},b:{b}")
+        # raise Exception('测试异常输出' * 5)
 
     # 发布任务
     for i in range(1, 51):
@@ -83,8 +86,8 @@ def t_demo5():
 
 if __name__ == '__main__':
     pass
-    # t_demo1()
-    # t_demo2()
+    t_demo1()
+    t_demo2()
     # t_demo3()
-    # t_demo4()
-    t_demo5()
\ No newline at end of file
+    t_demo4()
+    t_demo5()
